.. include:: introduction.rst

Spaces
##############

.. toctree::
   :titlesonly:

   Graph <Graph>
   Hyperbolic <Hyperbolic>
   HypercubeGraph <HypercubeGraph>
   Hypersphere <Hypersphere>
   Mesh <Mesh>
   SPD <SPD>
   SpecialOrthogonal <SpecialOrthogonal>
   SpecialUnitary <SpecialUnitary>
   Torus <Torus>

Backends
##############

.. toctree::
   :titlesonly:

   JAX (Graph space) <backends/JAX_Graph>
   PyTorch (Graph space) <backends/PyTorch_Graph>
   TensorFlow (Graph space) <backends/TensorFlow_Graph>

Frontends
##############

.. toctree::
   :titlesonly:

   GPFlow (Mesh space) <frontends/GPflow>
   GPJax (Mesh space) <frontends/GPJax>
   GPyTorch (Mesh space) <frontends/GPyTorch>

Other
##############

.. toctree::
   :titlesonly:
    
   Bayesian optimization on a sphere <other/Bayesian Optimization>
   Comparing approximations on Hyperbolic <other/Hyperbolic Approximations>
   Comparing approximations on SPD <other/SPD Approximations>
